package main

import (
	"log"
	"os"
	"os/signal"
	"syscall"
	"time"

	"gitea.smoothnet.org/nhyatt/go-temper/internal/temper"
	"github.com/prometheus/client_golang/prometheus"
)

func forever() {
	c := make(chan os.Signal, 1)
	signal.Notify(c, os.Interrupt, syscall.SIGTERM)
	<-c

	log.Println("[INFO] Shutdown signal received...")
}

func readTemp() {
	for {
		temp, err := temper.GetTemperature()
		if err != nil {
			log.Printf("[WARNING] Unable to get temperature from device: %v\n", err)
		} else {
			log.Printf(
				"[DEBUG] Temperature: %.2f°K %.2f°F %.2f°C\n",
				temp+273.15,
				9.0/5.0*temp+32,
				temp,
			)
			config.Prometheus.Temperature.With(prometheus.Labels{"unit": "celsius"}).Set(temp)
			config.Prometheus.Temperature.With(prometheus.Labels{"unit": "fahrenheit"}).Set(9.0/5.0*temp+32)
			config.Prometheus.Temperature.With(prometheus.Labels{"unit": "kelvin"}).Set(temp+273.15)
		}
		time.Sleep(time.Duration(5 * time.Second))
	}
}

func main() {
	initialize()

	go httpServer(config.WebSrvIP, config.WebSrvPort)

	go readTemp()

	forever()
}